HealPointsFu = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0");

HealPointsFu.hasIcon = "Interface\\Icons\\Spell_Holy_FlashHeal";
HealPointsFu.cannotDetachTooltip = true;
HealPointsFu.db = HealPoints.db

local int = { stat = "Intellect", statmod = 1 };
local spi = { stat = "Spirit", statmod = 1 };
local mp5 = { stat = "Mana/5s", statmod = 2.5 };
local heal = { stat = "+Healing", statmod = 0.455 };
local crit = { stat = "Spell Crit rating", statmod = 1 };
local haste = { stat = "Spell Haste rating", statmod = 1 };

local stats = { };
stats[1] = int;
stats[2] = spi;
stats[3] = mp5;
stats[4] = heal;
stats[5] = crit;
stats[6] = haste;

function HealPointsFu:OnTextUpdate()
  local function statToMenu(number, stat)
    stat.type = "execute";
    stat.name = number..": "..stat.stat;
    if stat.value then
      stat.desc = stat.value.." HealPoints/stat cost";
    else
      stat.desc = "N/A";
    end
    stat.func = function() end;
  end

  local function statTableSort(e1, e2)
    if (e1.value > e2.value) then
      return true;
    else
      return false;
    end;
  end

  if self:IsTextShown() then
		self:SetText(self:GetTitle())
	end

	if HealPoints.ISHEALER then
    local iv, sv, mv, hv, cv, h2v = HealPointsCalculator:computeHealPointsDelta();
    int.value = HealPointsUtil:round(iv / int.statmod);
    spi.value = HealPointsUtil:round(sv / spi.statmod);
    mp5.value = HealPointsUtil:round(mv / mp5.statmod);
    heal.value = HealPointsUtil:round(hv / heal.statmod);
    crit.value = HealPointsUtil:round(cv / crit.statmod);
    haste.value = HealPointsUtil:round(h2v / haste.statmod);
    table.sort(stats, statTableSort);
  end
  statToMenu(1, stats[1]);
  statToMenu(2, stats[2]);
  statToMenu(3, stats[3]);
  statToMenu(4, stats[4]);
  statToMenu(5, stats[5]);
  statToMenu(6, stats[6]);

  if (HealPoints.db.char.minimap == 0) then
    HealPointsFu:Hide();
  end    

end

function HealPointsFu:OnClick()
  if (HealPoints.ISHEALER and HealPoints:IsActive()) then
    if (HealPoints_CalcFrame:IsShown()) then
      HealPoints_CalcFrame:Hide();
    else
      HealPoints_CalcFrame:Show();
    end
  end
end

HealPointsFu.OnMenuRequest = {
  type = "group",
  args = {
    calc = {
      type = "execute",
      name = "Open Calculator",
      desc = "Open the calculator window.",
      order = 10,
      func = function()
        if (HealPoints.ISHEALER and HealPoints:IsActive()) then
  			  HealPoints_CalcFrame:Show();
  			end
      end
    },
    config = {
      type = "execute",
      name = "Open Config",
      desc = "Open the configuration window.",
      order = 11,
      func = function()
        if (HealPoints.ISHEALER and HealPoints:IsActive()) then
  			  HealPoints_ConfigFrame:Show();
  			end
      end
    },
    bscan = {
      type = "execute",
      name = "List special bonuses",
      desc = "List special set/equip bonuses detected.",
      order = 12,
      func = function()
        HealPoints:listScannedBonuses();
      end
    },

    spacer = {
      type = "header",
      order = 20,
    },
    mostvaluable = {
      type = "group",
      name = "Most valuable stat",
      desc = "Ranking of healing stats according to HealPoints per item budget cost.",
      order = 21,
      args = stats,
    },
    computemvs = {
      type = "execute",
      name = "Recompute valuable stats",
      desc = "Recompute the most valuable stat ranking according to current gear and buffs.",
      order = 22,
      func = "UpdateText",
    },

    gems = {
      type = "header",
      order = 30,
    },
    bluegems = {
      type = "group",
      name = "Blue Sockets",
      desc = "Select crafted, rare gem to be used for empty blue socket calculations.",
      order = 31,
      args = HealPointsGems.blueSocket,
    },
    redgems = {
      type = "group",
      name = "Red Sockets",
      desc = "Select crafted, rare gem to be used for empty red socket calculations.",
      order = 32,
      args = HealPointsGems.redSocket,
    },
    yellowgems = {
      type = "group",
      name = "Yellow Sockets",
      desc = "Select crafted, rare gem to be used for empty yellow socket calculations.",
      order = 33,
      args = HealPointsGems.yellowSocket,
    },

    options = {
      type = "header",
      order = 50,
    },
    tooltips = {
      type = "toggle",
      name = "Tooltip values",
      desc = "Toggles the display of HealPoints change in item tooltips.",
      order = 51,
      get = function()
        return HealPoints.db.char.tooltips == 1;
      end,
      set = function()
        HealPoints.db.char.tooltips = 1 - HealPoints.db.char.tooltips;
      end
    },
    debug = {
      type = "toggle",
      name = "Debug",
      desc = "Toggles the display of debug messages.",
      order = 52,
      get = function()
        return HealPoints.db.char.debug == 1;
      end,
      set = function()
        HealPoints:clearLinkCache();
        HealPoints.db.char.debug = 1 - HealPoints.db.char.debug;
      end
    },
    disable = {
      type = "execute",
      name = "Disable minimap icon",
      desc = "Disables the minimap icon / FuBar plugin.",
      order = 53,
      func = function()
        HealPoints.db.char.minimap = 0;
        HealPointsFu:Hide();      
      end
    },
  }
}
